import { 
  select, 
  csv, 
  scaleLinear, 
  extent, 
  axisLeft,
  axisBottom,
  format
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

var xAxisLabel, yAxisLabel, xValue, yValue;

const render = data => {
  xAxisLabel=document.getElementById("x_axis").value;
	yAxisLabel=document.getElementById("y_axis").value;
  //get x, y axis's label
  const title = xAxisLabel+' vs. '+yAxisLabel;
  
  switch(xAxisLabel){
    case "sepal_length": 
      xValue = d => d.sepal_length; 
      break;
    case "sepal_width": 
      xValue = d => d.sepal_width; 
      break;
    case "petal_length": 
      xValue = d => d.petal_length; 
      break;
    case "petal_width": 
      xValue = d => d.petal_width; 
      break;
  }
  switch(yAxisLabel){
    case "sepal_length": 
      yValue = d => d.sepal_length; 
      break;
    case "sepal_width": 
      yValue = d => d.sepal_width; 
      break;
    case "petal_length": 
      yValue = d => d.petal_length; 
      break;
    case "petal_width": 
      yValue = d => d.petal_width; 
      break;
  }
  
 	const circleRadius = 10;
  const margin = {top: 60, right: 40, bottom: 90, left: 150};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([innerHeight , 0])
  	.nice();
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(15);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.select('.domain').remove();
  
  yAxisG.append('text')
  	.attr('y', -93)
  	.attr('x', - innerHeight / 2)
  	.attr('fill', 'black')
  	.attr('class', 'axis-label')
  	.attr('transform', 'rotate(-90)')
  	.attr('text-anchor', 'middle')
  	.text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
  	.attr('y', 75)
  	.attr('x', innerWidth/2)
  	.attr('fill', 'black')
  	.attr('class', 'axis-label')
  	.text(xAxisLabel);
  
	g.selectAll('circle').data(data)
  	.enter().append('circle')
  		.attr('cy', d => yScale(yValue(d)) )
  		.attr('cx', d => xScale(xValue(d)))
  		.attr('r', circleRadius)
  		.attr('fill', d =>d.color);
  
  g.append('text')
  	.attr('class', 'title')
  	.attr('y', -10)
  	.text(title);
  
 
};

d3.select('button').on('click', function() { 
	d3.selectAll("svg > *").remove()	//remove the last data
    	csv('iris.csv')
  		//csv('http://vis.lab.djosix.com:2020/data/iris.csv')
      .then(data => {
       data.forEach(d => {
         d.sepal_length = +d.sepal_length;
         d.sepal_width = +d.sepal_width;
         d.petal_length = +d.petal_length;
         d.petal_width = +d.petal_width;
         if(d.species==="Iris-setosa"){
          d.color = '#f20707'; 
         }
         else if(d.species==="Iris-versicolor"){
          d.color = '#f2de07'; 
         }
         else{
           d.color = '#069c03';
         }
       });
       render(data);
    });
});

